<?php

/**
 * @file
 * Views integration for Entity Registration.
 */

use Drupal\Core\Entity\FieldableEntityInterface;

/**
 * Implements hook_views_data().
 */
function registration_views_data() {
  // Make views aware of custom area plugins.
  $data['views']['manage_registrations_caption'] = [
    'title' => t('Manage registrations caption'),
    'help' => t('Displays a caption for the Manage Registrations listing.'),
    'area' => [
      'id' => 'manage_registrations_caption',
    ],
  ];
  $data['views']['manage_registrations_empty'] = [
    'title' => t('Manage registrations empty'),
    'help' => t('Displays an empty notice for the Manage Registrations listing.'),
    'area' => [
      'id' => 'manage_registrations_empty',
    ],
  ];
  return $data;
}

/**
 * Implements hook_views_data_alter().
 */
function registration_views_data_alter(array &$data) {
  // Most registration fields are handled automatically by setting a
  // views_data class in the entity annotation. Derive additional data
  // for relationships. These are added one per fieldable entity type,
  // since there is a different base table for each.
  foreach (\Drupal::entityTypeManager()->getDefinitions() as $entity_type) {
    // Skip registration entity types to avoid circular references.
    $registration_entity_types = [
      'registration',
      'registration_settings',
    ];
    if (in_array($entity_type->id(), $registration_entity_types)) {
      continue;
    }

    // Ensure the entity type is fieldable.
    if ($entity_type->entityClassImplements(FieldableEntityInterface::class)) {
      $id = $entity_type->id();
      $base_table = $entity_type->getBaseTable();

      // Add a relationship from a host entity type to registrations.
      $data[$base_table][$base_table . '_registration'] = [
        'title' => t('@type registration', [
          '@type' => $entity_type->getLabel(),
        ]),
        'help' => t('Relate @type to their registrations.', [
          '@type' => $entity_type->getPluralLabel(),
        ]),
        'relationship' => [
          'id' => "registration",
          'label' => t('@id registration', [
            '@id' => $id,
          ]),
          'base' => 'registration',
        ],
      ];
      // Add a relationship from a host entity type to registration settings.
      $data[$base_table][$base_table . '_registration_settings'] = [
        'title' => t('@type registration settings', [
          '@type' => $entity_type->getLabel(),
        ]),
        'help' => t('Relate @type to their registration settings.', [
          '@type' => $entity_type->getPluralLabel(),
        ]),
        'relationship' => [
          'id' => "registration_settings",
          'label' => t('@id registration settings', [
            '@id' => $id,
          ]),
          'base' => 'registration_settings_field_data',
        ],
      ];
    }
  }

  // Make views aware of custom field plugins.
  $data['registration']['host_entity'] = [
    'title' => t('Host entity'),
    'group' => t('Registration'),
    'field' => [
      'title' => t('Host entity'),
      'help' => t('Displays the host entity for a registration.'),
      'id' => 'registration_host_entity',
    ],
  ];
  $data['registration_settings_field_data']['settings_operations'] = [
    'title' => t('Settings operations'),
    'help' => t('Provides links to perform settings operations.'),
    'field' => [
      'id' => 'registration_settings_operations',
    ],
  ];
}
